summaryrefslogtreecommitdiff
path: root/regcomp.c
diff options
context:
space:
mode:
authorKarl Williamson <public@khwilliamson.com>2010-12-26 10:35:58 -0700
committerKarl Williamson <public@khwilliamson.com>2011-01-16 19:13:22 -0700
commit50e911483ad5c29e25c54c9f81f92df974dd2cc0 (patch)
tree169549fc50823620e5f0ffed5c1c47ce10165d19 /regcomp.c
parent73134a2eb4055c76fe5b154da95e09118f716fd8 (diff)
downloadperl-50e911483ad5c29e25c54c9f81f92df974dd2cc0.tar.gz
Change name of /d to DEPENDS
I much prefer David Golden's name for /d whose meaning 'depends' on circumstances, instead of 'dual' meaning it could be one or another. Change it before this gets out in a stable release, and we're stuck with the old name.
Diffstat (limited to 'regcomp.c')
-rw-r--r--regcomp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/regcomp.c b/regcomp.c
index c57256d390..7d9e573913 100644
--- a/regcomp.c
+++ b/regcomp.c
@@ -4478,7 +4478,7 @@ Perl_re_compile(pTHX_ SV * const pattern, U32 orig_pm_flags)
#endif
/* Set to use unicode semantics if the pattern is in utf8 and has the
* 'dual' charset specified, as it means unicode when utf8 */
pm_flags = orig_pm_flags;
if (RExC_utf8 && get_regex_charset(pm_flags) == REGEX_DEPENDS_CHARSET) {
@@ -6335,7 +6335,7 @@ S_reg(pTHX_ RExC_state_t *pRExC_state, I32 paren, I32 *flagp,U32 depth)
cs = REGEX_UNICODE_CHARSET;
has_charset_modifier = 1;
break;
- case DUAL_PAT_MOD:
+ case DEPENDS_PAT_MOD:
if (has_use_defaults
|| has_charset_modifier
|| flagsp == &negflags)
@@ -4478,7 +4478,7 @@ Perl_re_compile(pTHX_ SV * const pattern, U32 orig_pm_flags)
#endif
/* Set to use unicode semantics if the pattern is in utf8 and has the
- * 'dual' charset specified, as it means unicode when utf8 */
+ * 'depends' charset specified, as it means unicode when utf8 */
pm_flags = orig_pm_flags;
if (RExC_utf8 && get_regex_charset(pm_flags) == REGEX_DEPENDS_CHARSET) {